import React from 'react';

import Input from '../../elements/Input';
import {ensureValue} from '../../elements/Validators';
import {shallow, mount, render} from 'enzyme';
import {expect} from 'chai';
import sinon from 'sinon';

describe('Static Rendered Markup', () => {
    describe('renders', () => {
        it('without parameters', () => {
            const wrapper = render(<Input />);
            const input = wrapper.find('input')
            expect(input.length).to.equal(1);
        });
    });

    describe('contains', () => {
        it('no attributes by default', () => {
            const wrapper = mount(
                <Input />
            );
            expect(wrapper.props()).to.deep.equal({});
        });

        it('expected properties when set', () => {
            const wrapper = mount(
                <Input attributes={{
                    type: 'email',
                    className: 'form-control',
                    id: 'email',
                    placeholder: 'E-Mail'
                }} />
            );
            expect(wrapper.props().attributes).to.deep.equal({
                type: 'email',
                className: 'form-control',
                id: 'email',
                placeholder: 'E-Mail'
            });
        });
    });
    
    describe('triggers on change event', () => {

        describe('without triggering an error', () => {
            const handleChange = sinon.spy();
            const wrapper = shallow(
                <Input onChange={handleChange} />
            );
            const event = {target: {value: 'hello world'}};
            const eventTypes = [
                'change',
                'onBlur'
            ]

            eventTypes.forEach((eventType) => {
                it(`on ${eventType} event`, () => {
                    wrapper.find('input').simulate(eventType, event);
                    expect(handleChange.args[0]).to.deep.equal([
                        { value: 'hello world' },
                        undefined,
                        false
                    ]);
                    expect(handleChange.calledOnce).to.equal(true);
                });
            });
        });

        describe('with an error', () => {
            const handleChange = sinon.spy();
            const wrapper = shallow(
                <Input validators={[ensureValue]} onChange={handleChange} />
            );
            const event = {target: {value: ''}};
            const eventTypes = [
                'change',
                'onBlur'
            ]

            eventTypes.forEach((eventType) => {
                it(`on ${eventType} event`, () => {
                    wrapper.find('input').simulate(eventType, event);
                    expect(handleChange.args[0]).to.deep.equal([
                        { value: '' },
                        'This field is required',
                        true
                    ]);
                    expect(handleChange.calledOnce).to.equal(true);
                });
            });
        });
    });
});
