import React from 'react';

import * as Validators from '../../elements/Validators';
import {expect} from 'chai';


describe('The ensure value validator', () => {
    describe('returns undefined when', () => {

        it('value is not an empty string', () => {
            expect(Validators.ensureValue('a')).to.be.undefined;
        });

        it('value is a cero', () => {
            expect(Validators.ensureValue(0)).to.be.undefined;
        });
    });

    describe('returns an error message when', () => {

        const msg = 'This field is required';

        it('value is empty string', () => {
            expect(Validators.ensureValue('')).to.be.equal(msg);
        });

        it('value is undefined', () => {
            expect(Validators.ensureValue()).to.be.equal(msg);
        });

    });

});

describe('The ensure email format validator', () => {
    describe('returns undefined when', () => {

        it('value is has proper format', () => {
            expect(Validators.ensureEmailFormat('test@test.local')).to.be.undefined;
        });

    });

    describe('returns an error message when', () => {

        const msg = 'This field requires a valid E-Mail format.';
        const invalidAddresses = [
            'hello.local',
            'Abc.example.com',
            'just"not"right@example.com',
            'this is"not\allowed@example.com',
            'this\ still\"not\\allowed@example.com',
            '1234567890123456789012345678901234567890123456789012345678901234+x@example.com',
            'john..doe@example.com',
            'example@localhost',
            'john.doe@example..com',
            ' @example.org'
        ];

        invalidAddresses.forEach((invalidEmail) => {
            it(`processing ${invalidEmail}`, () => {
                expect(Validators.ensureEmailFormat(invalidEmail)).to.be.equal(msg);
            });
        });

    });

});
